@@ -18,6 +18,7 @@ class HelpCommand:
             if not '_description' in detail:
                 continue
             msg += '    {:<15}        {}\n'.format(command, detail['_description'])
-
+            if hasattr(detail['_entry'], 'help'):
+                msg += '    {:<15}        {}\n'.format('', detail['_entry'].help())
         print(msg)
         return True
\ No newline at end of file
